OOpgrade
========

.. image:: https://travis-ci.org/gisce/oopgrade.svg?branch=master
    :target: https://travis-ci.org/gisce/oopgrade
.. image:: https://coveralls.io/repos/github/gisce/oopgrade/badge.svg?branch=master
    :target: https://coveralls.io/github/gisce/oopgrade?branch=master


.. note::
    The API is quite unstable due the active development

OpenObject upgrade lib forked from `openupgrade project <https://github.com/OCA/OpenUpgrade/tree/5.0/bin/openupgrade>`_
and improved and adapted to meed our needs.
